@@ -1444,7 +1444,7 @@ for(;;)
 					break;
 				}
 
-			DEBUG(fprintf(stderr,"TIMESCALE: "TTFormat" %cs\n",time_scale, time_dimension));
+			DEBUG(fprintf(stderr,"TIMESCALE: "TTFormat" %cs\n",GLOBALS->time_scale, GLOBALS->time_dimension));
 			sync_end(NULL);
 			}
 			break;
@@ -1484,7 +1484,7 @@ for(;;)
 					}
 
 				build_slisthier();
-				DEBUG(fprintf(stderr, "SCOPE: %s\n",slisthier));
+				DEBUG(fprintf(stderr, "SCOPE: %s\n",GLOBALS->slisthier));
 				}
 			sync_end(NULL);
 			break;
@@ -1515,7 +1515,7 @@ for(;;)
 					s=s->next;
 					}
 				build_slisthier();
-				DEBUG(fprintf(stderr, "SCOPE: %s\n",slisthier));
+				DEBUG(fprintf(stderr, "SCOPE: %s\n",GLOBALS->slisthier));
 				}
 				else
 				{
@@ -1907,10 +1907,6 @@ for(;;)
 					}
 				}
 
-			DEBUG(fprintf(stderr,"VAR %s %d %s %s[%d:%d]\n",
-				vartypes[v->vartype], v->size, v->id, v->name, 
-					v->msi, v->lsi));
-
 			goto bail;
 			err:
 			if(v)
@@ -3283,212 +3279,3 @@ if(GLOBALS->vlist_prepack)
 np->mv.mvlfac_vlist = NULL;
 }
 
-/*
- * $Id: vcd_recoder.c,v 1.56 2011/01/21 22:40:29 gtkwave Exp $
- * $Log: vcd_recoder.c,v $
- * Revision 1.56  2011/01/21 22:40:29  gtkwave
- * pass string lengths from api directly to code to avoid length calculations
- *
- * Revision 1.55  2011/01/18 00:00:12  gtkwave
- * preliminary tree component support
- *
- * Revision 1.54  2011/01/16 07:56:08  gtkwave
- * inlining of character get functions
- *
- * Revision 1.53  2011/01/13 17:20:39  gtkwave
- * rewrote hierarchy / facility packing code
- *
- * Revision 1.52  2010/12/19 07:59:10  gtkwave
- * warnings fixes
- *
- * Revision 1.51  2010/12/14 21:26:06  gtkwave
- * support XL-style identifiers for optimization detection in sym build
- *
- * Revision 1.50  2010/12/14 19:53:14  gtkwave
- * scaled back id multiplier from 95 to 94
- *
- * Revision 1.49  2010/12/12 18:32:45  gtkwave
- * add "string" variable type to parsing of vcd variable declarations
- *
- * Revision 1.48  2010/12/10 20:13:13  gtkwave
- * added escape codes to string record parsing
- *
- * Revision 1.47  2010/11/19 06:47:16  gtkwave
- * use PJE0 macro for unuser error return on judy function calls
- *
- * Revision 1.46  2010/11/07 16:20:33  gtkwave
- * make fst the default file format for --optimize action in gtkwave
- *
- * Revision 1.45  2010/09/29 00:24:41  gtkwave
- * allow range = 0 in VCD files for min and max times
- *
- * Revision 1.44  2010/09/24 15:44:41  gtkwave
- * changed large file size message to redirect to fst usage
- *
- * Revision 1.43  2010/06/02 03:51:30  gtkwave
- * don't autocoalesce escape identifiers
- *
- * Revision 1.42  2010/06/02 03:23:04  gtkwave
- * disable autocoalesce if Icarus Verilog is detected
- *
- * Revision 1.41  2010/03/18 17:12:37  gtkwave
- * pedantic warning cleanups
- *
- * Revision 1.40  2010/03/17 17:32:45  gtkwave
- * use calloc'd memory for SL iterator initialization
- *
- * Revision 1.39  2010/03/16 21:01:12  gtkwave
- * remove selected member of struct symbol
- *
- * Revision 1.38  2010/03/15 15:57:29  gtkwave
- * only allocate hash when necessary
- *
- * Revision 1.37  2010/03/14 07:09:49  gtkwave
- * removed ExtNode and merged with Node
- *
- * Revision 1.36  2010/03/13 19:48:53  gtkwave
- * remove nextinaet field and replace with temp symchain
- *
- * Revision 1.35  2010/03/13 07:56:41  gtkwave
- * removed unused h field in struct symbol
- *
- * Revision 1.34  2010/02/08 17:31:19  gtkwave
- * backtracking time fix
- *
- * Revision 1.33  2009/12/25 18:12:16  gtkwave
- * more warnings fixes
- *
- * Revision 1.32  2009/12/24 20:55:27  gtkwave
- * warnings cleanups
- *
- * Revision 1.31  2009/08/28 19:58:42  gtkwave
- * added malform_eof_fix
- *
- * Revision 1.30  2009/08/06 20:11:03  gtkwave
- * warnings fixes
- *
- * Revision 1.29  2009/07/07 19:46:03  gtkwave
- * make evcd->vcd conversion table const
- *
- * Revision 1.28  2009/07/07 15:48:37  gtkwave
- * EVCD "f" value fix (should be z not x)
- *
- * Revision 1.27  2009/07/06 21:41:36  gtkwave
- * evcd support issues
- *
- * Revision 1.26  2009/07/02 18:50:47  gtkwave
- * decorate VCD module trees with type info, add move to front to buildname
- *
- * Revision 1.25  2009/06/25 21:21:12  gtkwave
- * crash fix for zero bit wide events
- *
- * Revision 1.24  2009/06/25 18:31:19  gtkwave
- * added event types for VCD+FST and impulse arrows on event types
- *
- * Revision 1.23  2009/04/30 01:30:53  gtkwave
- * VCD parser fix for double subscripted nets
- *
- * Revision 1.22  2009/03/31 18:49:49  gtkwave
- * removal of warnings under cygwin compile
- *
- * Revision 1.21  2009/03/25 09:20:26  gtkwave
- * fixing reloader crashes in vcd_build_symbols if times is zero
- *
- * Revision 1.20  2009/03/05 16:17:56  gtkwave
- * added fastload option
- *
- * Revision 1.19  2008/12/25 03:52:32  gtkwave
- * -Wshadow warning fixes
- *
- * Revision 1.18  2008/10/12 02:56:20  gtkwave
- * fix for blackout regions
- *
- * Revision 1.17  2008/09/27 19:08:39  gtkwave
- * compiler warning fixes
- *
- * Revision 1.16  2008/09/17 04:33:39  gtkwave
- * support for smaller timescales in VCD files
- *
- * Revision 1.15  2008/08/22 20:19:12  gtkwave
- * fix for strings in vcd recoder
- *
- * Revision 1.14  2008/07/18 18:46:11  gtkwave
- * bitblasted vector relinking fix, disable hier pack in legacy+partial vcdload
- *
- * Revision 1.13  2008/07/18 18:23:07  gtkwave
- * fixes for aix
- *
- * Revision 1.12  2008/07/18 17:27:01  gtkwave
- * adding hierpack code
- *
- * Revision 1.11  2008/07/12 22:54:12  gtkwave
- * array of wires malformed vcd dump load abort fixed
- *
- * Revision 1.10  2008/07/11 07:02:54  gtkwave
- * recoder fix for malformed files
- *
- * Revision 1.9  2008/06/11 08:01:55  gtkwave
- * gcc 4.3.x compiler warning fixes
- *
- * Revision 1.8  2007/12/24 19:56:03  gtkwave
- * preparing for 3.1.2 version bump
- *
- * Revision 1.7  2007/12/18 17:28:54  gtkwave
- * added --giga command line option to gtkwave
- *
- * Revision 1.6  2007/12/17 18:49:32  gtkwave
- * added vlist_prepack rc variable which enables vlist_packer code
- *
- * Revision 1.5  2007/12/06 04:16:20  gtkwave
- * removed non-growable vlists
- *
- * Revision 1.4  2007/12/06 04:08:43  gtkwave
- * alias handling for freeze added (because of spill)
- *
- * Revision 1.3  2007/11/30 01:31:23  gtkwave
- * added vlist memory spill to disk code + fixed vcdload status bar on > 2GB
- *
- * Revision 1.2  2007/08/26 21:35:46  gtkwave
- * integrated global context management from SystemOfCode2007 branch
- *
- * Revision 1.1.1.1.2.7  2007/08/24 21:23:55  gtkwave
- * use setjump + potential backout ctx to "harden" vcd reload error recovery
- *
- * Revision 1.1.1.1.2.6  2007/08/07 03:18:56  kermin
- * Changed to pointer based GLOBAL structure and added initialization function
- *
- * Revision 1.1.1.1.2.5  2007/08/06 03:50:50  gtkwave
- * globals support for ae2, gtk1, cygwin, mingw.  also cleaned up some machine
- * generated structs, etc.
- *
- * Revision 1.1.1.1.2.4  2007/08/05 02:27:28  kermin
- * Semi working global struct
- *
- * Revision 1.1.1.1.2.3  2007/07/31 03:18:02  kermin
- * Merge Complete - I hope
- *
- * Revision 1.1.1.1.2.2  2007/07/28 19:50:40  kermin
- * Merged in the main line
- *
- * Revision 1.1.1.1  2007/05/30 04:27:29  gtkwave
- * Imported sources
- *
- * Revision 1.6  2007/05/28 00:55:06  gtkwave
- * added support for arrays as a first class dumpfile datatype
- *
- * Revision 1.5  2007/04/30 01:10:21  gtkwave
- * splash_sync() causes errno to be set when GTK main event loop is called
- * by the vcd parsers for newer versions of gnome (2.18) and/or other
- * various X11 Gentoo dependencies.
- *
- * Revision 1.4  2007/04/29 06:07:28  gtkwave
- * fixed memory leaks in vcd parser
- *
- * Revision 1.3  2007/04/29 04:13:49  gtkwave
- * changed anon union defined in struct Node to a named one as anon unions
- * are a gcc extension
- *
- * Revision 1.2  2007/04/20 02:08:17  gtkwave
- * initial release
- *
- */
